
taxa_ordering = ['species','genus','family','order','class','phylum','kingdom','domain']

most_complete_ordering = ['species','genus','tribe','family','order','cohort','legion','division','class','phylum','kingdom','realm','domain']